@@ -22,7 +22,7 @@ use File::Basename ();
 use File::Path ();
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -394,11 +394,14 @@ sub create_cluster_ok
     
     if(eval { $app->isa('Clustericious::App') })
     {
-      $app->helper(auth_ua => sub { 
-        die "no plug auth service configured for test cluster, either turn off authentication or use Test::Clustericious::Cluster#create_plugauth_lite_ok"
-          unless defined $self->{auth_ua};
-        $self->{auth_ua};
-      });
+      if($app->can('auth_ua'))
+      {
+        $app->helper(auth_ua => sub { 
+          die "no plug auth service configured for test cluster, either turn off authentication or use Test::Clustericious::Cluster#create_plugauth_lite_ok"
+            unless defined $self->{auth_ua};
+          $self->{auth_ua};
+        });
+      }
     }
 
     if($app && $app->isa('Clustericious::App'))
@@ -675,7 +678,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
